==> aioautomower-1.0.1-py3-none-any.whl: aioautomower/model/model_planner.py <==
"""Models for Automower Connect API - Planner."""

from dataclasses import dataclass, field
from datetime import datetime
from enum import StrEnum

from mashumaro import DataClassDictMixin, field_options

from .utils import convert_timestamp_to_aware_datetime


class Actions(StrEnum):
    """Actions in the planner of lawn mower."""

    NOT_ACTIVE = "not_active"
    FORCE_PARK = "force_park"
    FORCE_MOW = "force_mow"


@dataclass
class Override(DataClassDictMixin):
    """DataClass for Override values."""

    action: Actions = field(
        metadata=field_options(deserialize=lambda x: Actions(x.lower()))
    )


class RestrictedReasons(StrEnum):
    """Restricted reasons in the planner of lawn mower."""

    NONE = "none"
    WEEK_SCHEDULE = "week_schedule"
    PARK_OVERRIDE = "park_override"
    SENSOR = "sensor"
    DAILY_LIMIT = "daily_limit"
    FOTA = "fota"
    FROST = "frost"
    ALL_WORK_AREAS_COMPLETED = "all_work_areas_completed"
    EXTERNAL = "external"
    NOT_APPLICABLE = "not_applicable"


class ExternalReasons(StrEnum):
    """External reasons for restrictions."""

    GOOGLE_ASSISTANT = "google_assistant"
    AMAZON_ALEXA = "amazon_alexa"
    HOME_ASSISTANT = "home_assistant"
    IFTTT = "ifttt"
    IFTTT_WILDLIFE = "ifttt_wildlife"
    IFTTT_FROST_AND_RAIN_GUARD = "ifttt_frost_and_rain_guard"
    IFTTT_CALENDAR_CONNECTION = "ifttt_calendar_connection"
    GARDENA_SMART_SYSTEM = "gardena_smart_system"
    IFTTT_APPLETS = "ifttt_applets"
    DEVELOPER_PORTAL = "developer_portal"


def resolve_external_reason(reason_id: int) -> ExternalReasons | None:  # noqa: C901
    """Resolve the external reason based on the reason ID."""
    if 1000 <= reason_id <= 1999:
        return ExternalReasons.GOOGLE_ASSISTANT
    if 2000 <= reason_id <= 2999:
        return ExternalReasons.AMAZON_ALEXA
    if 3000 <= reason_id <= 3999:
        return ExternalReasons.HOME_ASSISTANT
    if reason_id == 4000:
        return ExternalReasons.IFTTT_WILDLIFE
    if reason_id == 4001:
        return ExternalReasons.IFTTT_FROST_AND_RAIN_GUARD
    if reason_id == 4002:
        return ExternalReasons.IFTTT_CALENDAR_CONNECTION
    if 4003 <= reason_id <= 4999:
        return ExternalReasons.IFTTT
    if 5000 <= reason_id <= 5999:
        return ExternalReasons.GARDENA_SMART_SYSTEM
    if 100000 <= reason_id <= 199999:
        return ExternalReasons.IFTTT_APPLETS
    if 200000 <= reason_id <= 299999:
        return ExternalReasons.DEVELOPER_PORTAL
    return None


@dataclass
class Planner(DataClassDictMixin):
    """DataClass for Planner values."""

    next_start_datetime: datetime | None = field(
        metadata=field_options(
            deserialize=convert_timestamp_to_aware_datetime,
            alias="nextStartTimestamp",
        ),
    )
    override: Override
    restricted_reason: RestrictedReasons = field(
        metadata=field_options(
            deserialize=lambda x: RestrictedReasons(x.lower()),
            alias="restrictedReason",
        )
    )
    external_reason: ExternalReasons | None = field(
        metadata=field_options(
            alias="externalReason",
            deserialize=lambda x: resolve_external_reason(int(x)),
        ),
        default=None,
    )

==> aioautomower-2025.4.1b0-py3-none-any.whl: aioautomower/model/model_planner.py <==
"""Models for Automower Connect API - Planner."""

from dataclasses import dataclass, field
from datetime import datetime
from enum import Enum, StrEnum

from mashumaro import DataClassDictMixin, field_options

from .utils import convert_timestamp_to_aware_datetime


@dataclass
class Override(DataClassDictMixin):
    """DataClass for Override values."""

    action: str = field(metadata=field_options(deserialize=lambda x: x.lower()))


@dataclass
class Planner(DataClassDictMixin):
    """DataClass for Planner values."""

    next_start_datetime: datetime | None = field(
        metadata=field_options(
            deserialize=convert_timestamp_to_aware_datetime,
            alias="nextStartTimestamp",
        ),
    )
    override: Override
    restricted_reason: str = field(
        metadata=field_options(
            deserialize=lambda x: x.lower(), alias="restrictedReason"
        )
    )


class Actions(StrEnum):
    """Actions in the planner of lawn mower."""

    NOT_ACTIVE = "not_active"
    FORCE_PARK = "force_park"
    FORCE_MOW = "force_mow"


class RestrictedReasons(StrEnum):
    """Restricted reasons in the planner of lawn mower."""

    NONE = "none"
    WEEK_SCHEDULE = "week_schedule"
    PARK_OVERRIDE = "park_override"
    SENSOR = "sensor"
    DAILY_LIMIT = "daily_limit"
    FOTA = "fota"
    FROST = "frost"
    ALL_WORK_AREAS_COMPLETED = "all_work_areas_completed"
    EXTERNAL = "external"
    NOT_APPLICABLE = "not_applicable"


class ExternalReasons(Enum):
    """External reasons for restrictions."""

    GOOGLE_ASSISTANT = range(1000, 1999)
    AMAZON_ALEXA = range(2000, 2999)
    DEVELOPER_PORTAL = range(3000, 3999), range(200000, 299999)
    IFTT = 4000, range(4003, 4999)
    IFTT_WILDLIFE = 4001
    IFTT_FROST_AND_RAIN = 4002
    IFTT_CALENDAR_CONNECTION = 4003
    IFTT_APPLETS = range(100000, 199999)


class InactiveReasons(Enum):
    """Inactive reasons why the mower is not working."""

    NONE = "none"
    PLANNING = "planing"
    SEARCHING_FOR_SATELLITES = "searching_for_satellites"
